@@ -23,6 +23,7 @@ from .literals import (
     GameStateType,
     GeneratedCodeJobStateType,
     OperationType,
+    ResultCodeType,
     StageStateType,
 )
 
@@ -35,92 +36,93 @@ else:
 __all__ = (
     "ConnectionTypeDef",
     "CreateGameRequestRequestTypeDef",
-    "CreateGameResultTypeDef",
+    "GameDetailsTypeDef",
+    "ResponseMetadataTypeDef",
     "CreateSnapshotRequestRequestTypeDef",
-    "CreateSnapshotResultTypeDef",
     "CreateStageRequestRequestTypeDef",
-    "CreateStageResultTypeDef",
+    "StageDetailsTypeDef",
     "DeleteGameRequestRequestTypeDef",
     "DeleteStageRequestRequestTypeDef",
+    "DeploymentResultTypeDef",
     "DisconnectPlayerRequestRequestTypeDef",
-    "DisconnectPlayerResultTypeDef",
     "ExportSnapshotRequestRequestTypeDef",
-    "ExportSnapshotResultTypeDef",
     "ExtensionDetailsTypeDef",
     "ExtensionVersionDetailsTypeDef",
-    "GameConfigurationDetailsTypeDef",
-    "GameDetailsTypeDef",
+    "SectionTypeDef",
     "GameSummaryTypeDef",
     "GeneratedCodeJobDetailsTypeDef",
     "GeneratorTypeDef",
     "GetExtensionRequestRequestTypeDef",
-    "GetExtensionResultTypeDef",
     "GetExtensionVersionRequestRequestTypeDef",
-    "GetExtensionVersionResultTypeDef",
     "GetGameConfigurationRequestRequestTypeDef",
-    "GetGameConfigurationResultTypeDef",
     "GetGameRequestRequestTypeDef",
-    "GetGameResultTypeDef",
     "GetGeneratedCodeJobRequestRequestTypeDef",
-    "GetGeneratedCodeJobResultTypeDef",
     "GetPlayerConnectionStatusRequestRequestTypeDef",
-    "GetPlayerConnectionStatusResultTypeDef",
     "GetSnapshotRequestRequestTypeDef",
-    "GetSnapshotResultTypeDef",
     "GetStageDeploymentRequestRequestTypeDef",
-    "GetStageDeploymentResultTypeDef",
     "GetStageRequestRequestTypeDef",
-    "GetStageResultTypeDef",
-    "ImportGameConfigurationRequestRequestTypeDef",
-    "ImportGameConfigurationResultTypeDef",
     "ImportGameConfigurationSourceTypeDef",
-    "ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
-    "ListExtensionVersionsRequestRequestTypeDef",
-    "ListExtensionVersionsResultTypeDef",
-    "ListExtensionsRequestListExtensionsPaginateTypeDef",
-    "ListExtensionsRequestRequestTypeDef",
-    "ListExtensionsResultTypeDef",
-    "ListGamesRequestListGamesPaginateTypeDef",
-    "ListGamesRequestRequestTypeDef",
-    "ListGamesResultTypeDef",
-    "ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
-    "ListGeneratedCodeJobsRequestRequestTypeDef",
-    "ListGeneratedCodeJobsResultTypeDef",
-    "ListSnapshotsRequestListSnapshotsPaginateTypeDef",
-    "ListSnapshotsRequestRequestTypeDef",
-    "ListSnapshotsResultTypeDef",
-    "ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
-    "ListStageDeploymentsRequestRequestTypeDef",
-    "ListStageDeploymentsResultTypeDef",
-    "ListStagesRequestListStagesPaginateTypeDef",
-    "ListStagesRequestRequestTypeDef",
-    "ListStagesResultTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "SectionModificationTypeDef",
-    "SectionTypeDef",
-    "SnapshotDetailsTypeDef",
+    "ListExtensionVersionsRequestRequestTypeDef",
+    "ListExtensionsRequestRequestTypeDef",
+    "ListGamesRequestRequestTypeDef",
+    "ListGeneratedCodeJobsRequestRequestTypeDef",
+    "ListSnapshotsRequestRequestTypeDef",
     "SnapshotSummaryTypeDef",
-    "StageDeploymentDetailsTypeDef",
-    "StageDeploymentSummaryTypeDef",
-    "StageDetailsTypeDef",
+    "ListStageDeploymentsRequestRequestTypeDef",
+    "ListStagesRequestRequestTypeDef",
     "StageSummaryTypeDef",
-    "StartGeneratedCodeJobRequestRequestTypeDef",
-    "StartGeneratedCodeJobResultTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "SectionModificationTypeDef",
     "StartStageDeploymentRequestRequestTypeDef",
-    "StartStageDeploymentResultTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateGameConfigurationRequestRequestTypeDef",
-    "UpdateGameConfigurationResultTypeDef",
     "UpdateGameRequestRequestTypeDef",
-    "UpdateGameResultTypeDef",
     "UpdateSnapshotRequestRequestTypeDef",
-    "UpdateSnapshotResultTypeDef",
     "UpdateStageRequestRequestTypeDef",
+    "CreateGameResultTypeDef",
+    "DisconnectPlayerResultTypeDef",
+    "ExportSnapshotResultTypeDef",
+    "GetGameResultTypeDef",
+    "GetPlayerConnectionStatusResultTypeDef",
+    "ListTagsForResourceResultTypeDef",
+    "StartGeneratedCodeJobResultTypeDef",
+    "UpdateGameResultTypeDef",
+    "CreateStageResultTypeDef",
+    "GetStageResultTypeDef",
     "UpdateStageResultTypeDef",
+    "StageDeploymentDetailsTypeDef",
+    "StageDeploymentSummaryTypeDef",
+    "GetExtensionResultTypeDef",
+    "ListExtensionsResultTypeDef",
+    "GetExtensionVersionResultTypeDef",
+    "ListExtensionVersionsResultTypeDef",
+    "GameConfigurationDetailsTypeDef",
+    "SnapshotDetailsTypeDef",
+    "ListGamesResultTypeDef",
+    "GetGeneratedCodeJobResultTypeDef",
+    "ListGeneratedCodeJobsResultTypeDef",
+    "StartGeneratedCodeJobRequestRequestTypeDef",
+    "ImportGameConfigurationRequestRequestTypeDef",
+    "ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+    "ListExtensionsRequestListExtensionsPaginateTypeDef",
+    "ListGamesRequestListGamesPaginateTypeDef",
+    "ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
+    "ListSnapshotsRequestListSnapshotsPaginateTypeDef",
+    "ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
+    "ListStagesRequestListStagesPaginateTypeDef",
+    "ListSnapshotsResultTypeDef",
+    "ListStagesResultTypeDef",
+    "UpdateGameConfigurationRequestRequestTypeDef",
+    "GetStageDeploymentResultTypeDef",
+    "StartStageDeploymentResultTypeDef",
+    "ListStageDeploymentsResultTypeDef",
+    "GetGameConfigurationResultTypeDef",
+    "ImportGameConfigurationResultTypeDef",
+    "UpdateGameConfigurationResultTypeDef",
+    "CreateSnapshotResultTypeDef",
+    "GetSnapshotResultTypeDef",
+    "UpdateSnapshotResultTypeDef",
 )
 
 ConnectionTypeDef = TypedDict(
@@ -155,11 +157,29 @@ class CreateGameRequestRequestTypeDef(
     pass
 
 
-CreateGameResultTypeDef = TypedDict(
-    "CreateGameResultTypeDef",
+GameDetailsTypeDef = TypedDict(
+    "GameDetailsTypeDef",
     {
-        "Game": "GameDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Arn": str,
+        "Created": datetime,
+        "Description": str,
+        "EnableTerminationProtection": bool,
+        "LastUpdated": datetime,
+        "Name": str,
+        "State": GameStateType,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -184,14 +204,6 @@ class CreateSnapshotRequestRequestTypeDef(
     pass
 
 
-CreateSnapshotResultTypeDef = TypedDict(
-    "CreateSnapshotResultTypeDef",
-    {
-        "Snapshot": "SnapshotDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredCreateStageRequestRequestTypeDef = TypedDict(
     "_RequiredCreateStageRequestRequestTypeDef",
     {
@@ -217,12 +229,21 @@ class CreateStageRequestRequestTypeDef(
     pass
 
 
-CreateStageResultTypeDef = TypedDict(
-    "CreateStageResultTypeDef",
+StageDetailsTypeDef = TypedDict(
+    "StageDetailsTypeDef",
     {
-        "Stage": "StageDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Arn": str,
+        "Created": datetime,
+        "Description": str,
+        "GameKey": str,
+        "LastUpdated": datetime,
+        "LogGroup": str,
+        "Name": str,
+        "Role": str,
+        "State": StageStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 DeleteGameRequestRequestTypeDef = TypedDict(
@@ -240,6 +261,15 @@ DeleteStageRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeploymentResultTypeDef = TypedDict(
+    "DeploymentResultTypeDef",
+    {
+        "Message": str,
+        "ResultCode": ResultCodeType,
+    },
+    total=False,
+)
+
 DisconnectPlayerRequestRequestTypeDef = TypedDict(
     "DisconnectPlayerRequestRequestTypeDef",
     {
@@ -249,15 +279,6 @@ DisconnectPlayerRequestRequestTypeDef = TypedDict(
     },
 )
 
-DisconnectPlayerResultTypeDef = TypedDict(
-    "DisconnectPlayerResultTypeDef",
-    {
-        "DisconnectFailures": List[str],
-        "DisconnectSuccesses": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ExportSnapshotRequestRequestTypeDef = TypedDict(
     "ExportSnapshotRequestRequestTypeDef",
     {
@@ -266,14 +287,6 @@ ExportSnapshotRequestRequestTypeDef = TypedDict(
     },
 )
 
-ExportSnapshotResultTypeDef = TypedDict(
-    "ExportSnapshotResultTypeDef",
-    {
-        "S3Url": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ExtensionDetailsTypeDef = TypedDict(
     "ExtensionDetailsTypeDef",
     {
@@ -295,27 +308,12 @@ ExtensionVersionDetailsTypeDef = TypedDict(
     total=False,
 )
 
-GameConfigurationDetailsTypeDef = TypedDict(
-    "GameConfigurationDetailsTypeDef",
+SectionTypeDef = TypedDict(
+    "SectionTypeDef",
     {
-        "Created": datetime,
-        "LastUpdated": datetime,
-        "Sections": Dict[str, "SectionTypeDef"],
-    },
-    total=False,
-)
-
-GameDetailsTypeDef = TypedDict(
-    "GameDetailsTypeDef",
-    {
-        "Arn": str,
-        "Created": datetime,
-        "Description": str,
-        "EnableTerminationProtection": bool,
-        "LastUpdated": datetime,
+        "Attributes": Dict[str, Any],
         "Name": str,
-        "State": GameStateType,
-        "Tags": Dict[str, str],
+        "Size": int,
     },
     total=False,
 )
@@ -361,14 +359,6 @@ GetExtensionRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetExtensionResultTypeDef = TypedDict(
-    "GetExtensionResultTypeDef",
-    {
-        "Extension": "ExtensionDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetExtensionVersionRequestRequestTypeDef = TypedDict(
     "GetExtensionVersionRequestRequestTypeDef",
     {
@@ -378,14 +368,6 @@ GetExtensionVersionRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetExtensionVersionResultTypeDef = TypedDict(
-    "GetExtensionVersionResultTypeDef",
-    {
-        "ExtensionVersion": "ExtensionVersionDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetGameConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredGetGameConfigurationRequestRequestTypeDef",
     {
@@ -408,14 +390,6 @@ class GetGameConfigurationRequestRequestTypeDef(
     pass
 
 
-GetGameConfigurationResultTypeDef = TypedDict(
-    "GetGameConfigurationResultTypeDef",
-    {
-        "GameConfiguration": "GameConfigurationDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetGameRequestRequestTypeDef = TypedDict(
     "GetGameRequestRequestTypeDef",
     {
@@ -423,14 +397,6 @@ GetGameRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetGameResultTypeDef = TypedDict(
-    "GetGameResultTypeDef",
-    {
-        "Game": "GameDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetGeneratedCodeJobRequestRequestTypeDef = TypedDict(
     "GetGeneratedCodeJobRequestRequestTypeDef",
     {
@@ -440,14 +406,6 @@ GetGeneratedCodeJobRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetGeneratedCodeJobResultTypeDef = TypedDict(
-    "GetGeneratedCodeJobResultTypeDef",
-    {
-        "GeneratedCodeJob": "GeneratedCodeJobDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetPlayerConnectionStatusRequestRequestTypeDef = TypedDict(
     "GetPlayerConnectionStatusRequestRequestTypeDef",
     {
@@ -457,14 +415,6 @@ GetPlayerConnectionStatusRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetPlayerConnectionStatusResultTypeDef = TypedDict(
-    "GetPlayerConnectionStatusResultTypeDef",
-    {
-        "Connections": List["ConnectionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetSnapshotRequestRequestTypeDef = TypedDict(
     "_RequiredGetSnapshotRequestRequestTypeDef",
     {
@@ -487,14 +437,6 @@ class GetSnapshotRequestRequestTypeDef(
     pass
 
 
-GetSnapshotResultTypeDef = TypedDict(
-    "GetSnapshotResultTypeDef",
-    {
-        "Snapshot": "SnapshotDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredGetStageDeploymentRequestRequestTypeDef = TypedDict(
     "_RequiredGetStageDeploymentRequestRequestTypeDef",
     {
@@ -518,14 +460,6 @@ class GetStageDeploymentRequestRequestTypeDef(
     pass
 
 
-GetStageDeploymentResultTypeDef = TypedDict(
-    "GetStageDeploymentResultTypeDef",
-    {
-        "StageDeployment": "StageDeploymentDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetStageRequestRequestTypeDef = TypedDict(
     "GetStageRequestRequestTypeDef",
     {
@@ -534,30 +468,6 @@ GetStageRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetStageResultTypeDef = TypedDict(
-    "GetStageResultTypeDef",
-    {
-        "Stage": "StageDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ImportGameConfigurationRequestRequestTypeDef = TypedDict(
-    "ImportGameConfigurationRequestRequestTypeDef",
-    {
-        "GameName": str,
-        "ImportSource": "ImportGameConfigurationSourceTypeDef",
-    },
-)
-
-ImportGameConfigurationResultTypeDef = TypedDict(
-    "ImportGameConfigurationResultTypeDef",
-    {
-        "GameConfiguration": "GameConfigurationDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ImportGameConfigurationSourceTypeDef = TypedDict(
     "ImportGameConfigurationSourceTypeDef",
     {
@@ -565,29 +475,16 @@ ImportGameConfigurationSourceTypeDef = TypedDict(
     },
 )
 
-_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
-    "_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "Name": str,
-        "Namespace": str,
-    },
-)
-_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
-    "_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef(
-    _RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
-    _OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListExtensionVersionsRequestRequestTypeDef = TypedDict(
     "_RequiredListExtensionVersionsRequestRequestTypeDef",
     {
@@ -612,23 +509,6 @@ class ListExtensionVersionsRequestRequestTypeDef(
     pass
 
 
-ListExtensionVersionsResultTypeDef = TypedDict(
-    "ListExtensionVersionsResultTypeDef",
-    {
-        "ExtensionVersions": List["ExtensionVersionDetailsTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListExtensionsRequestListExtensionsPaginateTypeDef = TypedDict(
-    "ListExtensionsRequestListExtensionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListExtensionsRequestRequestTypeDef = TypedDict(
     "ListExtensionsRequestRequestTypeDef",
     {
@@ -638,23 +518,6 @@ ListExtensionsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListExtensionsResultTypeDef = TypedDict(
-    "ListExtensionsResultTypeDef",
-    {
-        "Extensions": List["ExtensionDetailsTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListGamesRequestListGamesPaginateTypeDef = TypedDict(
-    "ListGamesRequestListGamesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListGamesRequestRequestTypeDef = TypedDict(
     "ListGamesRequestRequestTypeDef",
     {
@@ -664,38 +527,6 @@ ListGamesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListGamesResultTypeDef = TypedDict(
-    "ListGamesResultTypeDef",
-    {
-        "Games": List["GameSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
-    "_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
-    {
-        "GameName": str,
-        "SnapshotId": str,
-    },
-)
-_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
-    "_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef(
-    _RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
-    _OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListGeneratedCodeJobsRequestRequestTypeDef = TypedDict(
     "_RequiredListGeneratedCodeJobsRequestRequestTypeDef",
     {
@@ -720,37 +551,6 @@ class ListGeneratedCodeJobsRequestRequestTypeDef(
     pass
 
 
-ListGeneratedCodeJobsResultTypeDef = TypedDict(
-    "ListGeneratedCodeJobsResultTypeDef",
-    {
-        "GeneratedCodeJobs": List["GeneratedCodeJobDetailsTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
-    "_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef",
-    {
-        "GameName": str,
-    },
-)
-_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
-    "_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListSnapshotsRequestListSnapshotsPaginateTypeDef(
-    _RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef,
-    _OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListSnapshotsRequestRequestTypeDef = TypedDict(
     "_RequiredListSnapshotsRequestRequestTypeDef",
     {
@@ -773,38 +573,17 @@ class ListSnapshotsRequestRequestTypeDef(
     pass
 
 
-ListSnapshotsResultTypeDef = TypedDict(
-    "ListSnapshotsResultTypeDef",
+SnapshotSummaryTypeDef = TypedDict(
+    "SnapshotSummaryTypeDef",
     {
-        "NextToken": str,
-        "Snapshots": List["SnapshotSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
-    "_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
-    {
-        "GameName": str,
-        "StageName": str,
-    },
-)
-_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
-    "_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "Created": datetime,
+        "Description": str,
+        "Id": str,
+        "LastUpdated": datetime,
     },
     total=False,
 )
 
-
-class ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef(
-    _RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
-    _OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListStageDeploymentsRequestRequestTypeDef = TypedDict(
     "_RequiredListStageDeploymentsRequestRequestTypeDef",
     {
@@ -829,37 +608,6 @@ class ListStageDeploymentsRequestRequestTypeDef(
     pass
 
 
-ListStageDeploymentsResultTypeDef = TypedDict(
-    "ListStageDeploymentsResultTypeDef",
-    {
-        "NextToken": str,
-        "StageDeployments": List["StageDeploymentSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListStagesRequestListStagesPaginateTypeDef = TypedDict(
-    "_RequiredListStagesRequestListStagesPaginateTypeDef",
-    {
-        "GameName": str,
-    },
-)
-_OptionalListStagesRequestListStagesPaginateTypeDef = TypedDict(
-    "_OptionalListStagesRequestListStagesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListStagesRequestListStagesPaginateTypeDef(
-    _RequiredListStagesRequestListStagesPaginateTypeDef,
-    _OptionalListStagesRequestListStagesPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListStagesRequestRequestTypeDef = TypedDict(
     "_RequiredListStagesRequestRequestTypeDef",
     {
@@ -882,13 +630,16 @@ class ListStagesRequestRequestTypeDef(
     pass
 
 
-ListStagesResultTypeDef = TypedDict(
-    "ListStagesResultTypeDef",
+StageSummaryTypeDef = TypedDict(
+    "StageSummaryTypeDef",
     {
-        "NextToken": str,
-        "Stages": List["StageSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Description": str,
+        "GameKey": str,
+        "Name": str,
+        "State": StageStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
@@ -898,35 +649,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResultTypeDef = TypedDict(
-    "ListTagsForResourceResultTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 _RequiredSectionModificationTypeDef = TypedDict(
     "_RequiredSectionModificationTypeDef",
     {
@@ -950,110 +672,6 @@ class SectionModificationTypeDef(
     pass
 
 
-SectionTypeDef = TypedDict(
-    "SectionTypeDef",
-    {
-        "Attributes": Dict[str, Any],
-        "Name": str,
-        "Size": int,
-    },
-    total=False,
-)
-
-SnapshotDetailsTypeDef = TypedDict(
-    "SnapshotDetailsTypeDef",
-    {
-        "Created": datetime,
-        "Description": str,
-        "Id": str,
-        "LastUpdated": datetime,
-        "Sections": Dict[str, "SectionTypeDef"],
-    },
-    total=False,
-)
-
-SnapshotSummaryTypeDef = TypedDict(
-    "SnapshotSummaryTypeDef",
-    {
-        "Created": datetime,
-        "Description": str,
-        "Id": str,
-        "LastUpdated": datetime,
-    },
-    total=False,
-)
-
-StageDeploymentDetailsTypeDef = TypedDict(
-    "StageDeploymentDetailsTypeDef",
-    {
-        "Created": datetime,
-        "DeploymentAction": DeploymentActionType,
-        "DeploymentId": str,
-        "DeploymentState": DeploymentStateType,
-        "LastUpdated": datetime,
-        "SnapshotId": str,
-    },
-    total=False,
-)
-
-StageDeploymentSummaryTypeDef = TypedDict(
-    "StageDeploymentSummaryTypeDef",
-    {
-        "DeploymentAction": DeploymentActionType,
-        "DeploymentId": str,
-        "DeploymentState": DeploymentStateType,
-        "LastUpdated": datetime,
-        "SnapshotId": str,
-    },
-    total=False,
-)
-
-StageDetailsTypeDef = TypedDict(
-    "StageDetailsTypeDef",
-    {
-        "Arn": str,
-        "Created": datetime,
-        "Description": str,
-        "GameKey": str,
-        "LastUpdated": datetime,
-        "LogGroup": str,
-        "Name": str,
-        "Role": str,
-        "State": StageStateType,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-StageSummaryTypeDef = TypedDict(
-    "StageSummaryTypeDef",
-    {
-        "Description": str,
-        "GameKey": str,
-        "Name": str,
-        "State": StageStateType,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-StartGeneratedCodeJobRequestRequestTypeDef = TypedDict(
-    "StartGeneratedCodeJobRequestRequestTypeDef",
-    {
-        "GameName": str,
-        "Generator": "GeneratorTypeDef",
-        "SnapshotId": str,
-    },
-)
-
-StartGeneratedCodeJobResultTypeDef = TypedDict(
-    "StartGeneratedCodeJobResultTypeDef",
-    {
-        "GeneratedCodeJobId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredStartStageDeploymentRequestRequestTypeDef = TypedDict(
     "_RequiredStartStageDeploymentRequestRequestTypeDef",
     {
@@ -1078,14 +696,6 @@ class StartStageDeploymentRequestRequestTypeDef(
     pass
 
 
-StartStageDeploymentResultTypeDef = TypedDict(
-    "StartStageDeploymentResultTypeDef",
-    {
-        "StageDeployment": "StageDeploymentDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -1102,22 +712,6 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateGameConfigurationRequestRequestTypeDef = TypedDict(
-    "UpdateGameConfigurationRequestRequestTypeDef",
-    {
-        "GameName": str,
-        "Modifications": Sequence["SectionModificationTypeDef"],
-    },
-)
-
-UpdateGameConfigurationResultTypeDef = TypedDict(
-    "UpdateGameConfigurationResultTypeDef",
-    {
-        "GameConfiguration": "GameConfigurationDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateGameRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateGameRequestRequestTypeDef",
     {
@@ -1139,14 +733,6 @@ class UpdateGameRequestRequestTypeDef(
     pass
 
 
-UpdateGameResultTypeDef = TypedDict(
-    "UpdateGameResultTypeDef",
-    {
-        "Game": "GameDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateSnapshotRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateSnapshotRequestRequestTypeDef",
     {
@@ -1169,14 +755,6 @@ class UpdateSnapshotRequestRequestTypeDef(
     pass
 
 
-UpdateSnapshotResultTypeDef = TypedDict(
-    "UpdateSnapshotResultTypeDef",
-    {
-        "Snapshot": "SnapshotDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateStageRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateStageRequestRequestTypeDef",
     {
@@ -1200,10 +778,445 @@ class UpdateStageRequestRequestTypeDef(
     pass
 
 
+CreateGameResultTypeDef = TypedDict(
+    "CreateGameResultTypeDef",
+    {
+        "Game": GameDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DisconnectPlayerResultTypeDef = TypedDict(
+    "DisconnectPlayerResultTypeDef",
+    {
+        "DisconnectFailures": List[str],
+        "DisconnectSuccesses": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ExportSnapshotResultTypeDef = TypedDict(
+    "ExportSnapshotResultTypeDef",
+    {
+        "S3Url": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGameResultTypeDef = TypedDict(
+    "GetGameResultTypeDef",
+    {
+        "Game": GameDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetPlayerConnectionStatusResultTypeDef = TypedDict(
+    "GetPlayerConnectionStatusResultTypeDef",
+    {
+        "Connections": List[ConnectionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResultTypeDef = TypedDict(
+    "ListTagsForResourceResultTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartGeneratedCodeJobResultTypeDef = TypedDict(
+    "StartGeneratedCodeJobResultTypeDef",
+    {
+        "GeneratedCodeJobId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateGameResultTypeDef = TypedDict(
+    "UpdateGameResultTypeDef",
+    {
+        "Game": GameDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateStageResultTypeDef = TypedDict(
+    "CreateStageResultTypeDef",
+    {
+        "Stage": StageDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetStageResultTypeDef = TypedDict(
+    "GetStageResultTypeDef",
+    {
+        "Stage": StageDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateStageResultTypeDef = TypedDict(
     "UpdateStageResultTypeDef",
     {
-        "Stage": "StageDetailsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Stage": StageDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StageDeploymentDetailsTypeDef = TypedDict(
+    "StageDeploymentDetailsTypeDef",
+    {
+        "Created": datetime,
+        "DeploymentAction": DeploymentActionType,
+        "DeploymentId": str,
+        "DeploymentResult": DeploymentResultTypeDef,
+        "DeploymentState": DeploymentStateType,
+        "LastUpdated": datetime,
+        "SnapshotId": str,
+    },
+    total=False,
+)
+
+StageDeploymentSummaryTypeDef = TypedDict(
+    "StageDeploymentSummaryTypeDef",
+    {
+        "DeploymentAction": DeploymentActionType,
+        "DeploymentId": str,
+        "DeploymentResult": DeploymentResultTypeDef,
+        "DeploymentState": DeploymentStateType,
+        "LastUpdated": datetime,
+        "SnapshotId": str,
+    },
+    total=False,
+)
+
+GetExtensionResultTypeDef = TypedDict(
+    "GetExtensionResultTypeDef",
+    {
+        "Extension": ExtensionDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListExtensionsResultTypeDef = TypedDict(
+    "ListExtensionsResultTypeDef",
+    {
+        "Extensions": List[ExtensionDetailsTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetExtensionVersionResultTypeDef = TypedDict(
+    "GetExtensionVersionResultTypeDef",
+    {
+        "ExtensionVersion": ExtensionVersionDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListExtensionVersionsResultTypeDef = TypedDict(
+    "ListExtensionVersionsResultTypeDef",
+    {
+        "ExtensionVersions": List[ExtensionVersionDetailsTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GameConfigurationDetailsTypeDef = TypedDict(
+    "GameConfigurationDetailsTypeDef",
+    {
+        "Created": datetime,
+        "LastUpdated": datetime,
+        "Sections": Dict[str, SectionTypeDef],
+    },
+    total=False,
+)
+
+SnapshotDetailsTypeDef = TypedDict(
+    "SnapshotDetailsTypeDef",
+    {
+        "Created": datetime,
+        "Description": str,
+        "Id": str,
+        "LastUpdated": datetime,
+        "Sections": Dict[str, SectionTypeDef],
+    },
+    total=False,
+)
+
+ListGamesResultTypeDef = TypedDict(
+    "ListGamesResultTypeDef",
+    {
+        "Games": List[GameSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGeneratedCodeJobResultTypeDef = TypedDict(
+    "GetGeneratedCodeJobResultTypeDef",
+    {
+        "GeneratedCodeJob": GeneratedCodeJobDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListGeneratedCodeJobsResultTypeDef = TypedDict(
+    "ListGeneratedCodeJobsResultTypeDef",
+    {
+        "GeneratedCodeJobs": List[GeneratedCodeJobDetailsTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartGeneratedCodeJobRequestRequestTypeDef = TypedDict(
+    "StartGeneratedCodeJobRequestRequestTypeDef",
+    {
+        "GameName": str,
+        "Generator": GeneratorTypeDef,
+        "SnapshotId": str,
+    },
+)
+
+ImportGameConfigurationRequestRequestTypeDef = TypedDict(
+    "ImportGameConfigurationRequestRequestTypeDef",
+    {
+        "GameName": str,
+        "ImportSource": ImportGameConfigurationSourceTypeDef,
+    },
+)
+
+_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
+    "_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+    {
+        "Name": str,
+        "Namespace": str,
+    },
+)
+_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
+    "_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef(
+    _RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
+    _OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
+):
+    pass
+
+
+ListExtensionsRequestListExtensionsPaginateTypeDef = TypedDict(
+    "ListExtensionsRequestListExtensionsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListGamesRequestListGamesPaginateTypeDef = TypedDict(
+    "ListGamesRequestListGamesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
+    "_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
+    {
+        "GameName": str,
+        "SnapshotId": str,
+    },
+)
+_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
+    "_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef(
+    _RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
+    _OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
+    "_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef",
+    {
+        "GameName": str,
+    },
+)
+_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
+    "_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListSnapshotsRequestListSnapshotsPaginateTypeDef(
+    _RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef,
+    _OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
+    "_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
+    {
+        "GameName": str,
+        "StageName": str,
+    },
+)
+_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
+    "_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef(
+    _RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
+    _OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListStagesRequestListStagesPaginateTypeDef = TypedDict(
+    "_RequiredListStagesRequestListStagesPaginateTypeDef",
+    {
+        "GameName": str,
+    },
+)
+_OptionalListStagesRequestListStagesPaginateTypeDef = TypedDict(
+    "_OptionalListStagesRequestListStagesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListStagesRequestListStagesPaginateTypeDef(
+    _RequiredListStagesRequestListStagesPaginateTypeDef,
+    _OptionalListStagesRequestListStagesPaginateTypeDef,
+):
+    pass
+
+
+ListSnapshotsResultTypeDef = TypedDict(
+    "ListSnapshotsResultTypeDef",
+    {
+        "NextToken": str,
+        "Snapshots": List[SnapshotSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListStagesResultTypeDef = TypedDict(
+    "ListStagesResultTypeDef",
+    {
+        "NextToken": str,
+        "Stages": List[StageSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateGameConfigurationRequestRequestTypeDef = TypedDict(
+    "UpdateGameConfigurationRequestRequestTypeDef",
+    {
+        "GameName": str,
+        "Modifications": Sequence[SectionModificationTypeDef],
+    },
+)
+
+GetStageDeploymentResultTypeDef = TypedDict(
+    "GetStageDeploymentResultTypeDef",
+    {
+        "StageDeployment": StageDeploymentDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartStageDeploymentResultTypeDef = TypedDict(
+    "StartStageDeploymentResultTypeDef",
+    {
+        "StageDeployment": StageDeploymentDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListStageDeploymentsResultTypeDef = TypedDict(
+    "ListStageDeploymentsResultTypeDef",
+    {
+        "NextToken": str,
+        "StageDeployments": List[StageDeploymentSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGameConfigurationResultTypeDef = TypedDict(
+    "GetGameConfigurationResultTypeDef",
+    {
+        "GameConfiguration": GameConfigurationDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ImportGameConfigurationResultTypeDef = TypedDict(
+    "ImportGameConfigurationResultTypeDef",
+    {
+        "GameConfiguration": GameConfigurationDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateGameConfigurationResultTypeDef = TypedDict(
+    "UpdateGameConfigurationResultTypeDef",
+    {
+        "GameConfiguration": GameConfigurationDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateSnapshotResultTypeDef = TypedDict(
+    "CreateSnapshotResultTypeDef",
+    {
+        "Snapshot": SnapshotDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSnapshotResultTypeDef = TypedDict(
+    "GetSnapshotResultTypeDef",
+    {
+        "Snapshot": SnapshotDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateSnapshotResultTypeDef = TypedDict(
+    "UpdateSnapshotResultTypeDef",
+    {
+        "Snapshot": SnapshotDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
